aboutsummaryrefslogtreecommitdiffstatshomepage
path: root/drivers
diff options
context:
space:
mode:
authorRafael J. Wysocki <rafael.j.wysocki@intel.com>2019-04-04 22:08:47 +0200
committerRafael J. Wysocki <rafael.j.wysocki@intel.com>2019-04-04 22:08:47 +0200
commitb59fb7ef5240c301ca8b5b70d4298c0f053bb0c3 (patch)
treec8e08b455faf8801e31fa030e18c23df50b1bfd3 /drivers
parentACPI: use different default debug value than ACPICA (diff)
parentACPICA: Clear status of GPEs before enabling them (diff)
downloadwireguard-linux-b59fb7ef5240c301ca8b5b70d4298c0f053bb0c3.tar.xz
wireguard-linux-b59fb7ef5240c301ca8b5b70d4298c0f053bb0c3.zip
Merge branch 'acpica' into acpi
* acpica: ACPICA: Clear status of GPEs before enabling them
Diffstat (limited to 'drivers')
-rw-r--r--drivers/acpi/acpica/evgpe.c6
1 files changed, 5 insertions, 1 deletions
diff --git a/drivers/acpi/acpica/evgpe.c b/drivers/acpi/acpica/evgpe.c
index 62d3aa74277b..5e9d7348c16f 100644
--- a/drivers/acpi/acpica/evgpe.c
+++ b/drivers/acpi/acpica/evgpe.c
@@ -81,8 +81,12 @@ acpi_status acpi_ev_enable_gpe(struct acpi_gpe_event_info *gpe_event_info)
ACPI_FUNCTION_TRACE(ev_enable_gpe);
- /* Enable the requested GPE */
+ /* Clear the GPE status */
+ status = acpi_hw_clear_gpe(gpe_event_info);
+ if (ACPI_FAILURE(status))
+ return_ACPI_STATUS(status);
+ /* Enable the requested GPE */
status = acpi_hw_low_set_gpe(gpe_event_info, ACPI_GPE_ENABLE);
return_ACPI_STATUS(status);
}